@@ -4,7 +4,10 @@ from StringIO import StringIO
 
 from django.core.files.base import ContentFile
 
-from sorl.thumbnail import ImageField
+try:
+    from sorl.thumbnail import ImageField
+except ImportError:
+    from django.db.models import ImageField
 
 
 class ResizedImageFieldFile(ImageField.attr_class):
@@ -12,7 +15,6 @@ class ResizedImageFieldFile(ImageField.attr_class):
     def save(self, name, content, save=True):
         new_content = StringIO()
         content.file.seek(0)
-
         img = Image.open(content.file)
         img.thumbnail((
             self.field.max_width, 
@@ -29,7 +31,7 @@ class ResizedImageField(ImageField):
     
     attr_class = ResizedImageFieldFile
 
-    def __init__(self, verbose_name=None, name=None, upload_to='', max_width=800, max_height=600, storage=None, **kwargs):
-        self.max_width = max_width
-        self.max_height = max_height
-        super(ResizedImageField, self).__init__(verbose_name, name, upload_to, storage, **kwargs) 
+    def __init__(self, verbose_name=None, name=None, **kwargs):
+        self.max_width = kwargs.get('max_width', 800)
+        self.max_height = kwargs.get('max_height', 600)
+        super(ResizedImageField, self).__init__(verbose_name, name, **kwargs) 
